@@ -13,7 +13,7 @@ from fabric import Connection, task
 from invoke import Collection  # noqa, re-export
 
 
-__version__ = "1.0.20200907"
+__version__ = "1.0.20200924"
 
 
 # I don't care, in this context.
@@ -78,7 +78,7 @@ def pre_commit_hook():
     path = config.base / ".git" / "hooks" / "pre-commit"
     if not path.exists():
         with path.open("w") as hook:
-            hook.write("#!/bin/sh\nfab check\n")
+            hook.write("#!/bin/sh\nfl check\n")
         path.chmod(0o755)
 
 
@@ -100,7 +100,7 @@ def _dbname_from_domain(domain):
 
 
 def _concurrently(ctx, jobs):
-    with tempfile.NamedTemporaryFile("w+", prefix="fab.", suffix=".sh") as f:
+    with tempfile.NamedTemporaryFile("w+", prefix="fl.", suffix=".sh") as f:
         jobs = "\n".join(f"{job} &" for job in jobs)
         # https://gist.github.com/jiaaro/b2e1b7c705022c2cf56888152a999f65
         f.write(
@@ -128,7 +128,7 @@ def dev(ctx, host="127.0.0.1", port=8000):
         ctx,
         [
             f"venv/bin/python manage.py runserver 0.0.0.0:{port}",
-            f'HOST="{host}" yarn run webpack-dev-server'
+            f'HOST="{host}" node_modules/.bin/webpack-dev-server'
             f" --host 0.0.0.0 --port 4000 --hot",
         ],
     )
@@ -222,9 +222,9 @@ def upgrade(ctx, stable=False):
     """Re-create the virtualenv with newest versions of all libraries"""
     run(ctx, "rm -rf venv")
     run(ctx, f"{_python3()} -m venv venv")
-    run(ctx, "venv/bin/pip install -U pip wheel setuptools")
+    run(ctx, "venv/bin/python -m pip install -U pip wheel setuptools")
     extra = "" if stable else "--pre"
-    run(ctx, f"venv/bin/pip install -U -r requirements-to-freeze.txt {extra}")
+    run(ctx, f"venv/bin/python -m pip install -U -r requirements-to-freeze.txt {extra}")
     freeze(ctx)
 
 
@@ -233,7 +233,7 @@ def freeze(ctx):
     """Freeze the virtualenv's state"""
     run(
         ctx,
-        '(printf "# AUTOGENERATED, DO NOT EDIT\n\n";' "venv/bin/pip freeze -l"
+        '(printf "# AUTOGENERATED, DO NOT EDIT\n\n";' "venv/bin/python -m pip freeze -l"
         # Until Ubuntu gets its act together:
         ' | grep -vE "(^pkg-resources)"' ") > requirements.txt",
     )
@@ -245,8 +245,8 @@ def update(ctx):
     venv = config.base / "venv"
     if not venv.exists():
         run(ctx, f"{_python3()} -m venv venv")
-    run(ctx, "venv/bin/pip install -U pip wheel setuptools")
-    run(ctx, "venv/bin/pip install -r requirements.txt")
+    run(ctx, "venv/bin/python -m pip install -U pip wheel setuptools")
+    run(ctx, "venv/bin/python -m pip install -r requirements.txt")
     run(ctx, 'find . -name "*.pyc" -delete')
     run(ctx, "yarn")
     run(ctx, "venv/bin/python manage.py migrate")
@@ -281,6 +281,7 @@ def _local_dbname():
 @task
 def local(ctx):
     """Local environment setup"""
+    run(ctx, "rm -rf node_modules venv")
     dbname = _local_dbname()
     run(ctx, f"createdb {dbname}", warn=True)
     update(ctx)
@@ -300,8 +301,8 @@ def nine_vhost(ctx):
             run(conn, "mkdir -f media tmp")
 
 
-@task
-def nine_alias_add(ctx, alias):
+@task(auto_shortflags=False, help={"include-www": "Include the www. subdomain"})
+def nine_alias_add(ctx, alias, include_www=False):
     """Add aliasses to a nine-manage-vhost virtual host"""
     with Connection(config.host) as conn:
         run(
@@ -309,16 +310,17 @@ def nine_alias_add(ctx, alias):
             f"sudo nine-manage-vhosts alias create --virtual-host={config.domain}"
             f" {alias}",
         )
-        run(
-            conn,
-            f"sudo nine-manage-vhosts alias create --virtual-host={config.domain}"
-            f" www.{alias}",
-            warn=True,
-        )
+        if include_www:
+            run(
+                conn,
+                f"sudo nine-manage-vhosts alias create --virtual-host={config.domain}"
+                f" www.{alias}",
+                warn=True,
+            )
 
 
-@task
-def nine_alias_remove(ctx, alias):
+@task(auto_shortflags=False, help={"include-www": "Include the www. subdomain"})
+def nine_alias_remove(ctx, alias, include_www=False):
     """Remove aliasses from a nine-manage-vhost virtual host"""
     with Connection(config.host) as conn:
         run(
@@ -326,12 +328,13 @@ def nine_alias_remove(ctx, alias):
             f"sudo nine-manage-vhosts alias remove --virtual-host={config.domain}"
             f" {alias}",
         )
-        run(
-            conn,
-            f"sudo nine-manage-vhosts alias create --virtual-host={config.domain}"
-            f" www.{alias}",
-            warn=True,
-        )
+        if include_www:
+            run(
+                conn,
+                f"sudo nine-manage-vhosts alias remove --virtual-host={config.domain}"
+                f" www.{alias}",
+                warn=True,
+            )
 
 
 @task
@@ -449,9 +452,10 @@ def nine_venv(ctx):
     """Create a venv and install packages from requirements.txt"""
     with Connection(config.host) as conn:
         with conn.cd(config.domain):
+            run(conn, "rm -rf venv")
             run(conn, "PATH=~/.pyenv/shims:$PATH python3 -m venv venv")
-            run(conn, "venv/bin/pip install -U pip wheel setuptools")
-            run(conn, "venv/bin/pip install -r requirements.txt")
+            run(conn, "venv/bin/python -m pip install -U pip wheel setuptools")
+            run(conn, "venv/bin/python -m pip install -r requirements.txt")
 
 
 @task
@@ -514,13 +518,13 @@ def _check_django(ctx):
 def _check_prettier(ctx):
     run(
         ctx,
-        f"yarn run prettier --list-different --no-semi"
+        f"node_modules/.bin/prettier --list-different --no-semi"
         f' "*.js" "{config.app}/static/**/*.js" "{config.app}/static/**/*.scss"',
     )
 
 
 def _check_eslint(ctx):
-    run(ctx, f'yarn run eslint "*.js" {config.app}/static')
+    run(ctx, f'node_modules/.bin/eslint "*.js" {config.app}/static')
 
 
 def _check_branch(ctx):
@@ -541,7 +545,7 @@ def check(ctx):
 def _fmt_prettier(ctx):
     run(
         ctx,
-        f"yarn run prettier --write --no-semi"
+        f"node_modules/.bin/prettier --write --no-semi"
         f' "*.js" "{config.app}/static/**/*.js" "{config.app}/static/**/*.scss"',
     )
 
@@ -577,7 +581,7 @@ def deploy(ctx):
     _check_branch(ctx)
     check(ctx)
     run(ctx, f"git push origin {config.branch}")
-    run(ctx, "NODE_ENV=production yarn run webpack -p --bail")
+    run(ctx, "NODE_ENV=production node_modules/.bin/webpack -p --bail")
 
     with Connection(config.host) as conn:
         with conn.cd(config.domain):
@@ -585,8 +589,8 @@ def deploy(ctx):
             run(conn, "git fetch origin")
             run(conn, f"git merge --ff-only origin/{config.branch}")
             run(conn, 'find . -name "*.pyc" -delete')
-            run(conn, "venv/bin/pip install -U pip wheel setuptools")
-            run(conn, "venv/bin/pip install -r requirements.txt")
+            run(conn, "venv/bin/python -m pip install -U pip wheel setuptools")
+            run(conn, "venv/bin/python -m pip install -r requirements.txt")
             run(conn, "venv/bin/python manage.py migrate")
             run(conn, "venv/bin/python manage.py check --deploy", warn=True)
             run(
